@@ -172,12 +172,11 @@ class PlayerClient(Player):
                                         'title', title))
             else:
                 tracks |= set(self.find('musicbrainz_artistid', artist.mbid))
-        else:
-            for name in artist.names:
-                if title:
-                    tracks |= set(self.find('artist', name, 'title', title))
-                else:
-                    tracks |= set(self.find('artist', name))
+        for name in artist.names:
+            if title:
+                tracks |= set(self.find('artist', name, 'title', title))
+            else:
+                tracks |= set(self.find('artist', name))
         return list(tracks)
 
     @bl_artist
@@ -198,8 +197,6 @@ class PlayerClient(Player):
             if exact_m:
                 _ = [artist.add_alias(name) for name in exact_m]
                 found = True
-        else:
-            artist = Artist(name=artist.name)
         # then complete with fuzzy search on artist with no musicbrainz_artistid
         if artist.mbid:
             # we already performed a lookup on artists with mbid set
@@ -215,12 +212,13 @@ class PlayerClient(Player):
         # Does not perform fuzzy matching on short and single word strings
         # Only lowercased comparison
         if ' ' not in artist.name and len(artist.name) < 8:
-            for fuzz_art in match:
+            for close_art in match:
                 # Regular lowered string comparison
-                if artist.name.lower() == fuzz_art.lower():
-                    artist.add_alias(fuzz_art)
+                if artist.name.lower() == close_art.lower():
+                    artist.add_alias(close_art)
                     return artist
-        fzartist = SimaStr(artist.name)
+                else:
+                    return
         for fuzz_art in match:
             # Regular lowered string comparison
             if artist.name.lower() == fuzz_art.lower():
@@ -230,7 +228,7 @@ class PlayerClient(Player):
                     self.log.debug('"%s" matches "%s".', fuzz_art, artist)
                 continue
             # SimaStr string __eq__ (not regular string comparison here)
-            if fzartist == fuzz_art:
+            if SimaStr(artist.name) == fuzz_art:
                 found = True
                 artist.add_alias(fuzz_art)
                 self.log.info('"%s" quite probably matches "%s" (SimaStr)',
@@ -249,28 +247,26 @@ class PlayerClient(Player):
         match = get_close_matches(title, all_artist_titles, 50, 0.78)
         if not match:
             return []
-        for title_ in match:
-            leven = levenshtein_ratio(title.lower(), title_.lower())
+        for mtitle in match:
+            leven = levenshtein_ratio(title.lower(), mtitle.lower())
             if leven == 1:
                 pass
             elif leven >= 0.79:  # PARAM
                 self.log.debug('title: "%s" should match "%s" (lr=%1.3f)',
-                               title_, title, leven)
+                               mtitle, title, leven)
             else:
                 self.log.debug('title: "%s" does not match "%s" (lr=%1.3f)',
-                               title_, title, leven)
+                               mtitle, title, leven)
                 return []
-            return self.find('artist', artist, 'title', title_)
+            return self.find('artist', artist, 'title', mtitle)
 
     def find_album(self, artist, album):
         """
         Special wrapper around album search:
         Album lookup is made through AlbumArtist/Album instead of Artist/Album
+        MPD falls back to Artist if AlbumArtist is not found  (cf. documentation)
         """
-        alb_art_search = self.find('albumartist', artist, 'album', album)
-        if alb_art_search:
-            return alb_art_search
-        return self.find('artist', artist, 'album', album)
+        return self.find('albumartist', artist, 'album', album)
 
     @blacklist(album=True)
     def search_albums(self, artist):
@@ -339,6 +335,18 @@ class PlayerClient(Player):
     def state(self):
         return str(self.status().get('state'))
 
+    @property
+    def playmode(self):
+        plm = {'repeat': None,
+               'single': None,
+               'random': None,
+               'consume': None,
+              }
+        for key, val in self.status().items():
+            if key in plm.keys():
+                plm.update({key:bool(int(val))})
+        return plm
+
     @property
     def current(self):
         return self.currentsong()
